Module z_syslog_logger

An access logger which gets its log entries from an ets buffer and writes them to syslog.

Copyright © 2015-2021 Maas-Maarten Zeeman

Behaviours: gen_server.

Authors: Maas-Maarten Zeeman (mmzeeman@xs4all.nl).

Description

An access logger which gets its log entries from an ets buffer and writes them to syslog

Function Index

handle_call/3
handle_cast/2
init/1Initialize the logger.
log/1Format the reguest.
start_link/0

Function Details

handle_call/3

handle_call(X1, From, State) -> any()

handle_cast/2

handle_cast(Msg, State) -> any()

init/1

init(X1) -> any()

Initialize the logger.

log/1

log(Http_log_access) -> any()

Format the reguest. We use a format similar to apache's vhost_commont The site and dispatch rule is also included in the log line.

start_link/0

start_link() -> any()


Generated by EDoc